/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.samples.stats;

import org.wso2.registry.jdbc.handlers.EditProcessor;
import org.wso2.registry.exceptions.RegistryException;
import org.wso2.registry.Resource;
import org.wso2.registry.Registry;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.impl.builder.StAXOMBuilder;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.namespace.QName;

public class ESBStatisticsEditProcessor extends EditProcessor {

    public void processEdit(
            String path,
            String editViewName,
            HttpServletRequest request,
            HttpServletResponse response) throws RegistryException {

        if ("basic".equals(editViewName)) {

            String serverName = request.getParameter("server-name");
            String serverPath = request.getParameter("server-path");

            Registry registry = getRegistry(request);
            Resource resource = registry.get(path);

            OMElement docElement;
            try {
                StAXOMBuilder builder = new StAXOMBuilder(resource.getContentStream());
                docElement = builder.getDocumentElement();
            } catch (Exception ae) {
                throw new RegistryException("Failed to parse the esb statistics file. " +
                        "All statistics should be in XML format.");
            }

            OMElement serverElement = docElement.getFirstChildWithName(new QName("server"));
            OMElement serverNameElement = serverElement.getFirstChildWithName(new QName("name"));
            serverNameElement.setText(serverName);

            OMElement serverPathElement = serverElement.getFirstChildWithName(new QName("path"));
            serverPathElement.setText(serverPath);

            docElement.build();

            resource.setContent(docElement.toString());
            registry.put(path, resource);

        } else if ("details".equals(editViewName)) {

            String contentString = request.getParameter("stats");

            Registry registry = getRegistry(request);
            Resource resource = registry.get(path);
            resource.setContent(contentString);
            registry.put(path, resource);
        }
    }
}
